A helper function to check that the input data frame is OK
Source:R/eca-internal-funcs.R
check_refmix.RdJust checks to make sure that column types are correct.
R/eca-internal-funcs.R
check_refmix.RdJust checks to make sure that column types are correct.