a vector that gives a desired sort order of the chinook collections
Source:R/data.R
chinook_collection_levels.RdThis is just an example of what one would use as levels in order to
get the chinook collections in a desired sort order after
analysis. The issue here is collection in the input data frame to most
functions must be a character vector, not a factor. But, after analysis
you can always make them a factor again and use a vector like this
one to specify the levels.