This is just like the chinook data, but only has 7 loci and all loci are
fixed in fortuitous patterns so that every single collection is easily resolved. This is
primarily useful for testing purposes.
This is just like the chinook data, but only has 7 loci and all loci are
fixed in fortuitous patterns so that every single collection is easily resolved. This is
primarily useful for testing purposes.