read a gsi_sim formatted input file into a tibble that rubias can use
Source:R/read_gsi_sim.R
read_gsi_sim.RdNote that this relies on a system call to awk. It probably won't work on Windows.
Arguments
- path
path to the gsi_sim file
- sample_type
should be "reference" or "mixture" depending on what kind of file it is
- repunits
the gsi_sim reporting units file. Has no effect if sample_type is "mixture". If sample_type is "reference" and this is left as NULL, then all collections will be put in the the "default_repu".