List of example ways of specifying repunit and collection quantities in simulations
Source:R/data.R
sim_spec_examples.RdThis is just a list of tibbles that can be passed to the alpha_repunit or the
alpha_collection parameters in, for example, assess_reference_loo.