List-izes the output of reference_allele_counts into a usable format for allelic_list
Value
a_freq_list returns a list named by loci, each element of which is a matrix
containing that locus's allele count data. Rows in the matrix mark alleles, and columns collections
Examples
# Generate a list of individual genotypes by allele from
# the alewife data's reference allele count tables
example(reference_allele_counts)
#>
#> rfrn__> ## count alleles in alewife reference populations
#> rfrn__> example(tcf2long) # gets variable ale_long
#>
#> tcf2ln> ## Convert the alewife dataset for further processing
#> tcf2ln> # the data frame passed into this function must have had
#> tcf2ln> # character collections and repunits converted to factors
#> tcf2ln> reference <- alewife
#>
#> tcf2ln> reference$repunit <- factor(reference$repunit, levels = unique(reference$repunit))
#>
#> tcf2ln> reference$collection <- factor(reference$collection, levels = unique(reference$collection))
#>
#> tcf2ln> ale_long <- tcf2long(reference, 17)
#>
#> rfrn__> ale_rac <- reference_allele_counts(ale_long$long)
ale_ac <- a_freq_list(ale_rac)