Calculates the posterior probability that the sample contains at least one fish from each collection and repunit
Source:R/prob_at_least_one_in_sample.R
prob_at_least_one_in_sample.RdThis takes the output of infer_mixture() and returns two tibbles, one for collections and the other for repunits. Note that for this to work properly, infer_mixture() must have been run with a total_catch_tib, and also it is imperative that the variable_prob_is_catch parameter to infer_mixture() was at its default value of FALSE.