powered by
Takes a matrix in which columns sum to one. For each column, performs a single multinomial draw from the rows, weighted by their values in that column
samp_from_mat(M)
a vector length = ncol(M) of indices, with each element being the row that was chosen in that column's sampling
ncol(M)
a matrix whose columns are reals summing to one