Do leave-one-out self-assignment of individuals in a reference baseline
Source:R/self_assign.R
self_assign.RdReturns a tidy data frame
Usage
self_assign(
reference,
gen_start_col,
preCompiledParams = NULL,
alle_freq_prior = list(const_scaled = 1)
)Arguments
- reference
a two-column format genetic dataset, with "repunit", "collection", and "indiv" columns, as well as a "sample_type" column that has some "reference" entries
- gen_start_col
the first column of genetic data in
reference- preCompiledParams
Users should never use this option. It is here only so that this function can be called on a precompiled set of parameters with infer_mixture. Don't use this, unless you are one of the package developers...
- alle_freq_prior
a one-element named list specifying the prior to be used when generating Dirichlet parameters for genotype likelihood calculations. Valid methods include
"const","scaled_const", and"empirical". See?list_diploid_paramsfor method details.
Examples
ale_sa <- self_assign(alewife, 17)
#> Summary Statistics:
#>
#> 1070 Individuals in Sample
#>
#> 11 Loci: Aa046, Aa070, Aa074, Aa081, Aa091, Aa093, Ap010, Ap033, Ap038, Ap058, Ap071
#>
#> 3 Reporting Units: NNE, SNE, MAT
#>
#> 21 Collections: EMA, STG, PIS, MYS, MON, TBR, GIL, THA, BRI, CON, QUI, HOU, PEQ, MIA, HUD, DEL, NAN, RAP, CHO, ROA, ALL
#>
#> 6.31% of allelic data identified as missing